@@ -30,6 +30,7 @@ __all__ = (
     "RecommendationCategoryType",
     "RepositoryAssociationStateType",
     "RepositoryAssociationSucceededWaiterName",
+    "SeverityType",
     "TypeType",
     "VendorNameType",
 )
@@ -61,5 +62,6 @@ RepositoryAssociationStateType = Literal[
     "Associated", "Associating", "Disassociated", "Disassociating", "Failed"
 ]
 RepositoryAssociationSucceededWaiterName = Literal["repository_association_succeeded"]
+SeverityType = Literal["Critical", "High", "Info", "Low", "Medium"]
 TypeType = Literal["PullRequest", "RepositoryAnalysis"]
 VendorNameType = Literal["GitHub", "GitLab", "NativeS3"]
